@@ -3,15 +3,12 @@ import json
 import logging
 import platform
 
-
 import socketio
-from aiortc import RTCPeerConnection, RTCRtpSender
+from aiortc import RTCPeerConnection, RTCRtpSender, RTCConfiguration, RTCIceServer
 from aiortc.contrib.media import MediaPlayer, MediaRelay
 
-
 raspberry = True
 
-
 relay = None
 webcam = None
 camera = None
@@ -94,7 +91,12 @@ class GSPeerConnectionBroadcaster:
 
         @self.sio.event
         async def watcher(id):
-            pc = RTCPeerConnection()
+            pc = RTCPeerConnection(configuration=RTCConfiguration([
+                RTCIceServer("stun:stun.l.google:19302"),
+                RTCIceServer(self.gsdbs.credentials["turnserver"],
+                             self.gsdbs.credentials["turnuser"],
+                             self.gsdbs.credentials["turnpw"]),
+            ]))
             self.peerConnections[id] = pc
 
             audio, video = self.create_local_tracks_new(
